EXPORTS
	?NotifyDevmonEvent@RUsbHostStack@@QAEXAAVTRequestStatus@@AAH@Z @ 1 NONAME ; void RUsbHostStack::NotifyDevmonEvent(class TRequestStatus &, int &)
	?EnableDriverLoading@RUsbHostStack@@QAEHXZ @ 2 NONAME ; int RUsbHostStack::EnableDriverLoading(void)
	?Version@RUsbHostStack@@QBE?AVTVersion@@XZ @ 3 NONAME ; class TVersion RUsbHostStack::Version(void) const
	?NotifyDeviceEvent@RUsbHostStack@@QAEXAAVTRequestStatus@@AAVTDeviceEventInformation@@@Z @ 4 NONAME ; void RUsbHostStack::NotifyDeviceEvent(class TRequestStatus &, class TDeviceEventInformation &)
	??0RUsbHostStack@@QAE@XZ @ 5 NONAME ; RUsbHostStack::RUsbHostStack(void)
	?DisableDriverLoading@RUsbHostStack@@QAEXXZ @ 6 NONAME ; void RUsbHostStack::DisableDriverLoading(void)
	?__DbgFailNext@RUsbHostStack@@QAEHH@Z @ 7 NONAME ; int RUsbHostStack::__DbgFailNext(int)
	?__DbgAlloc@RUsbHostStack@@QAEHXZ @ 8 NONAME ; int RUsbHostStack::__DbgAlloc(void)
	?GetProductStringDescriptor@RUsbHostStack@@QAEHIIAAV?$TBuf@$0IA@@@@Z @ 9 NONAME ; int RUsbHostStack::GetProductStringDescriptor(unsigned int, unsigned int, class TBuf<128> &)
	?NotifyDeviceEventCancel@RUsbHostStack@@QAEXXZ @ 10 NONAME ; void RUsbHostStack::NotifyDeviceEventCancel(void)
	?GetOtgDescriptor@RUsbHostStack@@QAEHIAAVTOtgDescriptor@@@Z @ 11 NONAME ; int RUsbHostStack::GetOtgDescriptor(unsigned int, class TOtgDescriptor &)
	?NotifyDevmonEventCancel@RUsbHostStack@@QAEXXZ @ 12 NONAME ; void RUsbHostStack::NotifyDevmonEventCancel(void)
	?Connect@RUsbHostStack@@QAEHXZ @ 13 NONAME ; int RUsbHostStack::Connect(void)
	?GetManufacturerStringDescriptor@RUsbHostStack@@QAEHIIAAV?$TBuf@$0IA@@@@Z @ 14 NONAME ; int RUsbHostStack::GetManufacturerStringDescriptor(unsigned int, unsigned int, class TBuf<128> &)
	?GetConfigurationDescriptor@RUsbHostStack@@QAEHIAAVTConfigurationDescriptor@@@Z @ 15 NONAME ; int RUsbHostStack::GetConfigurationDescriptor(unsigned int, class TConfigurationDescriptor &)
	?GetSupportedLanguages@RUsbHostStack@@QAEHIAAV?$RArray@I@@@Z @ 16 NONAME ; int RUsbHostStack::GetSupportedLanguages(unsigned int, class RArray<unsigned int> &)

